@@ -87,9 +87,26 @@ class DlgConfig:
       operateur = QtGui.QLabel()
       operateur.setText(u"Opérateur")
       self.comboop = QtGui.QComboBox()
-      self.comboop.addItem("Bouygues Telecom")
-      self.comboop.addItem("SFR")
-      #self.comboop.addItem("Orange")
+      
+      operators = [('Bouygues Telecom', 'bouygues.png'),
+                   ('SFR', 'sfr.png'),
+#                   ('Orange', 'orange.png')
+                   ]
+
+      iconPath = '/opt/qonso/icons'
+      if not os.path.exists(iconPath):
+         iconPath = 'icons'
+
+      index=0
+      currentIndex=0
+      for op, iconFile in operators:
+         icon = QtGui.QIcon(os.path.join(iconPath, iconFile))
+         self.comboop.addItem(icon, op)
+         if op==self.GetOperator():
+            currentIndex = index
+         index += 1
+#      self.comboop.setStyleSheet("padding: 2px")
+      self.comboop.setCurrentIndex(currentIndex)
       hLayoutCombo.addWidget(operateur)
       hLayoutCombo.addWidget(self.comboop)
       
