@@ -39,16 +39,17 @@ class QonsoView(QtGui.QMainWindow):
       self.vbox = QtGui.QVBoxLayout()
       self.centralWidget.setLayout(self.vbox)
       self.setCentralWidget( self.centralWidget )
-
+      self.firstDisplay = None
+      
       self.credentialsOk = True
       self.CreateAppLayouts()
 
       if self.offline:
-         self.CreateConsoLayouts()
          self.CreateExtractor(sys.argv[1])
          f = open( sys.argv[2], "r")
          self.extractor.ExtractDatas( f.read() )
          f.close()
+         self.CreateConsoLayouts()
 
    def CreateExtractor(self, op):
       self.extractor = QonsoFactory.CreateExtractor(op)
@@ -89,9 +90,17 @@ class QonsoView(QtGui.QMainWindow):
       voixBox = self.CreateLayout('voix', os.path.join(iconPath, 'voix.png'), True)
       self.vbox.addLayout(voixBox)
       
+      if self.model.GetConsoVoixSupp('str'):
+         voixSupBox = self.CreateLayout('voixSupp', os.path.join(iconPath, 'voixsupp.png'), True)
+         self.vbox.addLayout(voixSupBox)
+      
       if self.model.GetConsoSMSMax() != '0':
          smsBox = self.CreateLayout('sms', os.path.join(iconPath, 'sms.png') )
          self.vbox.addLayout(smsBox)
+      
+      if self.model.GetConsoSMSSupp():
+         smsSupBox = self.CreateLayout('smsSupp', os.path.join(iconPath, 'smssupp.png') )
+         self.vbox.addLayout(smsSupBox)
          
       dataBox = self.CreateLayout('data', os.path.join(iconPath, 'data.png'), True)
       self.vbox.addLayout(dataBox)
@@ -112,7 +121,7 @@ class QonsoView(QtGui.QMainWindow):
          pixicon = QtGui.QPixmap(icon).scaled(64,64)
          label = QtGui.QLabel()
          label.setMinimumSize(QtCore.QSize(74, 74))
-         label.setMaximumSize(QtCore.QSize(96, 200))
+         label.setMaximumSize(QtCore.QSize(96, 250))
          label.setStyleSheet("background: #fff; margin: 0; padding: 5px; border-bottom: 1px solid #269CCA;")
          label.setPixmap(pixicon)
          box.addWidget(label)
@@ -121,9 +130,10 @@ class QonsoView(QtGui.QMainWindow):
 
       sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
       sizePolicy.setHorizontalStretch(1)
+      sizePolicy.setVerticalStretch(1)
       sizePolicy.setHeightForWidth(data.sizePolicy().hasHeightForWidth())
       data.setSizePolicy(sizePolicy)
-      data.setMaximumSize(QtCore.QSize(800, 134))
+      data.setMaximumSize(QtCore.QSize(800, 800))
       data.setStyleSheet("background: #fff;")
       data.setAlignment(QtCore.Qt.AlignCenter)
       
@@ -133,12 +143,11 @@ class QonsoView(QtGui.QMainWindow):
       
       if progress:
          wid = WProgress(self)
-         wid.setStyleSheet("background: #fff; margin: 0; padding: 5px; border-bottom: 1px solid #269CCA")
+         wid.setStyleSheet("background: #fff; margin: 0; padding: 10px; border-bottom: 1px solid #269CCA")
          vbox.addWidget(wid)
          wid.setMaximumSize(QtCore.QSize(800, 70))
       else:
          data.setStyleSheet("background: #fff; margin: 0; padding: 5px; border-bottom: 1px solid #269CCA")
-         data.setMaximumSize(QtCore.QSize(800, 134))
 
       box.addLayout(vbox)
          
@@ -149,7 +158,7 @@ class QonsoView(QtGui.QMainWindow):
       status, context = self.extractor.GetStatus()
       
       if status=='ERROR':
-         self.SetText(self.labels['lasttime'][0], "#FF0000", 10, context)
+         self.SetText(self.labels['lasttime'][0], "#FF0000", 15, context)
       else:
          if not self.model.GetLastTime():
             self.SetText(self.labels['lasttime'][0], "#269CCA", 16, context)
@@ -158,22 +167,30 @@ class QonsoView(QtGui.QMainWindow):
                          "<br/>"+self.model.GetReport('str'))
          
       if self.labels.has_key('voix'):
-         self.SetText(self.labels['voix'][0], "#EB5F18", 22, self.model.GetConsoVoix('str')+" / "+self.model.GetConsoVoixMax('str') )
+         self.SetText(self.labels['voix'][0], "#EB5F18", 20, self.model.GetConsoVoix('str')+" / "+self.model.GetConsoVoixMax('str') )
          self.labels['voix'][1].setRange(0, self.model.GetConsoVoixMax('int'))
          self.labels['voix'][1].setValue( self.model.GetConsoVoix('int') )
 
+      if self.labels.has_key('voixSupp'):
+         self.SetText(self.labels['voixSupp'][0], "#EB5F18", 20, self.model.GetConsoVoixSupp('str')+" / "+self.model.GetConsoVoixSuppMax('str') )
+         self.labels['voixSupp'][1].setRange(0, self.model.GetConsoVoixMax('int'))
+         self.labels['voixSupp'][1].setValue( self.model.GetConsoVoixSuppMax('int') )
+
       if self.model.GetConsoSMSMax() != '0':
-         self.SetText(self.labels['sms'][0], "#EB5F18", 22, self.model.GetConsoSMS() +"/" + self.model.GetConsoSMSMax())
+         self.SetText(self.labels['sms'][0], "#EB5F18", 20, self.model.GetConsoSMS() +"/" + self.model.GetConsoSMSMax())
+
+      if self.labels.has_key('smsSupp'):
+         self.SetText(self.labels['smsSupp'][0], "#EB5F18", 20, self.model.GetConsoSMSSupp() +"/" + self.model.GetConsoSMSSuppMax())
 
       if self.labels.has_key('data'):
          dataMax = self.model.GetConsoDataMax()
          data = self.model.GetConsoData()
-         self.SetText(self.labels['data'][0], "#EB5F18", 22, str(data)+" / "+str(dataMax)+"Mo")
+         self.SetText(self.labels['data'][0], "#EB5F18", 20, str(data)+" / "+str(dataMax)+"Mo")
          self.labels['data'][1].setRange(0, dataMax)
          self.labels['data'][1].setValue( data )
       
       if self.labels.has_key('hforfait'):
-         self.SetText(self.labels['hforfait'][0], "#EB5F18", 22, self.model.GetConsoHorsForfait() )
+         self.SetText(self.labels['hforfait'][0], "#EB5F18", 20, self.model.GetConsoHorsForfait() )
          
       if self.labels.has_key('facture'):
          self.SetText(self.labels['facture'][0], "#269CCA", 16, self.model.GetDateProchaineFacture())
@@ -182,14 +199,15 @@ class QonsoView(QtGui.QMainWindow):
       label.setText('<span style="color: %s; font-weight: bold; font-size: %dpt">%s</span>' % (color, size, text))
    
    def paintEvent(self, event):
-      if self.credentialsOk and not self.extractor.authentication:
-         if not self.offline:
-            self.extractor.InitAuthenticate()
-      elif self.layoutsOK:
-         if self.extractor.datasExtracted:
-            self.CreateConsoLayouts()
-            self.extractor.datasExtracted = False 
-            
+      if self.firstDisplay:
+         if self.credentialsOk and not self.extractor.authentication:
+            if not self.offline:
+               self.extractor.InitAuthenticate()
+         elif self.layoutsOK:
+            if self.extractor.datasExtracted:
+               self.CreateConsoLayouts()
+               self.extractor.datasExtracted = False 
+      self.firstDisplay = True
       self.UpdateConsoText()
       
    def closeEvent(self, event):
